<?php
namespace Faturamento\Logic\Cda;

/**
 * Regras de negócio relacionadas ao filtro da tela de CDA (Controle Diário de Atividades).
 *
 * @author newtonsantos
 */
class FiltroCda {

    public static function getDadosOperadorFiltroCda() {
        $ambiente = \Geral\Util\Ambiente::getInstancia();
        
        /**
         * Código do funcionário relacionado ao operador logado 
         */
        $cdempresa = $ambiente->getOperador()->getFunc()->getCdempresa();
        $cdfunc = $ambiente->getOperador()->getFunc()->getCdfunc();
        
        /**
         * Verifica permissão para visualização/manutenção dos CDAs 
         * de outros funcionários de acordo com os grupos de operador
         * aos quais o operador está relacionado.
         */
        $cdoperador = $ambiente->getCdOperador();
        $nrorg = $ambiente->getNrorg();

        $gruposDoOperador = \Geral\Entities\Opergrupop::findByCdoperadorAndNrorg($cdoperador, $nrorg);

        $permitePesqFunc = false;
        foreach ($gruposDoOperador as $grupo) {
            $cdgrupoper = $grupo->getCdgrupoper();

            $autgrupop = \Producao\Entities\Autgrupop::findByCdgrupoperAndIdautgrupopAndNrorg($cdgrupoper, 'ACSA', $nrorg);
            if (count($autgrupop) > 0) {
                $permitePesqFunc = true;
                break;
            }

            $autgrupop = \Producao\Entities\Autgrupop::findByCdgrupoperAndIdautgrupopAndNrorg($cdgrupoper, 'DPAP', $nrorg);
            if (count($autgrupop) > 0) {
                $permitePesqFunc = true;
                break;
            }
        }

        /** 
         * Código do tipo de admissão do funcionário relacionado ao operador 
         * logado.
         */
        $cdtpadmissao = $ambiente->getOperador()->getFunc()->getCdtpadmissao();
        
        /**
         * Verifica o período atual de acordo com a data de hoje
         */
        $dtperiodo = self::getPeriodoapurapontoAtual($nrorg, $cdempresa, $cdfunc, $cdtpadmissao);
        
        /* Monta o array contendo os valores que serão retornados 
         */
        $dadosfiltrocda = array(
            'cdfunc'          => $cdfunc,
            'permitepesqfunc' => $permitePesqFunc,
            'cdtpadmissao'    => $cdtpadmissao,
            'dtperiodo'       => $dtperiodo
        );
        
        return $dadosfiltrocda;

    }
    
    public static function getPeriodoapurapontoAtual($nrorg, $cdempresa, $cdfunc, $cdtpadmissao) {
        $func = \Geral\Entities\Funcionario::findOneByCdempresaAndCdfuncAndNrorg($cdempresa, $cdfunc, $nrorg);
        if(is_object($func)) {
            $dtdeslfunc = $func->getDtDeslFunc();
        } else {
            $dtdeslfunc = '';
        } 
        if(is_null($dtdeslfunc) || $dtdeslfunc == '') {
            $dtatual = \Geral\Util\DateUtil::subtraiIntervalo(\Geral\Util\DateUtil::getDataAtual(true), 1);
        } else {
            $dtatual = $dtdeslfunc;
        }
        $stdtatual  = \Geral\Util\DateUtil::getAno($dtatual);
        $stdtatual .= \Geral\Util\DateUtil::getMes($dtatual);
        $stdtatual .= \Geral\Util\DateUtil::getDia($dtatual);
        
        if(is_null($cdtpadmissao) || $cdtpadmissao == '') {
            $cdtpadmissao = "C";
        }
        
        $where = "(CDTPADMISSAO = ?) AND (TO_DATE(?, 'YYYYMMDD') BETWEEN DTINICIALAPURAPONTO AND DTFINALAPURAPONTO) AND (NRORG = ?)";
        $params = array($cdtpadmissao, $stdtatual, $nrorg);
        $fpa_periodoapuraponto = \Folha\Entities\Fpaperiodoapuraponto::getObjectByWhere($where, $params);
        if(!is_object($fpa_periodoapuraponto)){
            $where = "(CDTPADMISSAO = ?) AND (NRORG = ?) AND (DTINICIALAPURAPONTO = (SELECT MAX(DTINICIALAPURAPONTO) FROM FPA_PERIODOAPURAPONTO WHERE (CDTPADMISSAO = ?) AND (NRORG = ?) AND (DTINICIALAPURAPONTO <= TO_DATE(?, 'YYYYMMDD'))))";
            $params = array($cdtpadmissao, $nrorg, $cdtpadmissao, $nrorg, $stdtatual);
            $fpa_periodoapuraponto = \Folha\Entities\Fpaperiodoapuraponto::getObjectByWhere($where, $params);
        }
        
        $dtinicial = $fpa_periodoapuraponto->getDtinicialapuraponto();
        $dtfinal = $fpa_periodoapuraponto->getDtfinalapuraponto();
        $idperiodoapuraponto = $fpa_periodoapuraponto->getIdperiodoapuraponto();
        $dtperiodo  = $dtinicial->format(\Geral\Util\DateUtil::FORMATO_BRASILEIRO);
        $dtperiodo .= ',';
        $dtperiodo .= $dtfinal->format(\Geral\Util\DateUtil::FORMATO_BRASILEIRO);
        $dtperiodo .= ',';
        $dtperiodo .= $idperiodoapuraponto;
        
        return $dtperiodo;
    }
    
    public static function getTipoAdmissaoFunc($nrorg, $cdempresa, $cdfunc) {
        $func = \Geral\Entities\Funcionario::findOneByCdempresaAndCdfuncAndNrorg($cdempresa, $cdfunc, $nrorg);

        $cdtpadmissao = '';
        if(is_object($func)) {
            $cdtpadmissao = $func->getCdtpadmissao();
        } 
        
        return $cdtpadmissao;
    }
    
}

?>
